@@ -36,9 +36,7 @@
 #include <string.h>
 
 #ifndef __cplusplus
-/*
 #include  <cfortHdf.h>
-*/
 #endif
 
 #ifdef   _HDFEOS5_THREADSAFE
@@ -46,7 +44,7 @@
 #endif
 
 
-#define HE5_HDFEOSVERSION "1.17"
+#define HE5_HDFEOSVERSION "1.15"
 
 #define H5_USE_16_API 1
 
@@ -141,7 +139,7 @@ typedef struct
 
 
 
-/*
+/* 
  ----------------------------------------------
  |     Compound Dataset Information Data      |
  |               Structure                    |
@@ -154,7 +152,7 @@ typedef struct
   int            rank[HE5_FLDNUMBERMAX];   /* Fields rank array        */
   int            array[HE5_FLDNUMBERMAX];  /* Flag if field is an array*/
   char           *fieldname[HE5_FLDNUMBERMAX];/* Array of field names     */
-                                              /* Array of dimension sizes */
+                                              /* Array of dimension sizes */ 
   size_t         dims[HE5_FLDNUMBERMAX][HE5_DTSETRANKMAX];
   size_t         datasize;                 /* Size of data (bytes)     */
   size_t         offset[HE5_FLDNUMBERMAX]; /* Array of field offsets   */
@@ -163,11 +161,11 @@ typedef struct
   H5T_class_t    dclass[HE5_FLDNUMBERMAX]; /* Array of field class IDs */
 }HE5_CmpDTSinfo;
 
-typedef  struct
+typedef  struct 
 {
   long        count;     /* Object counter */
   long        strsize;   /* Operator data  */
-  char        *name;     /* Object name    */
+  char        *name;     /* Object name    */ 
 }HE5_OBJINFO;
 
 /* File access flags for TOOLKIT */
@@ -199,77 +197,77 @@ typedef  struct
 /* Data type flags for FORTRAN wrappers */
 /* ------------------------------------ */
 #ifndef    HE5F_ACC_RDWR
-#define    HE5F_ACC_RDWR           100
+#define    HE5F_ACC_RDWR           100 
 #endif
 #ifndef    HE5F_ACC_RDONLY
-#define    HE5F_ACC_RDONLY         101
+#define    HE5F_ACC_RDONLY         101 
 #endif
 #ifndef    HE5F_ACC_TRUNC
-#define    HE5F_ACC_TRUNC          102
+#define    HE5F_ACC_TRUNC          102 
 #endif
 
-#define    HE5T_NATIVE_INT           ((hid_t) 0)
-#define    HE5T_NATIVE_UINT          ((hid_t) 1)
-#define    HE5T_NATIVE_SHORT         ((hid_t) 2)
-#define    HE5T_NATIVE_USHORT        ((hid_t) 3)
-#define    HE5T_NATIVE_SCHAR         ((hid_t) 4)
-#define    HE5T_NATIVE_UCHAR         ((hid_t) 5)
-#define    HE5T_NATIVE_LONG          ((hid_t) 6)
-#define    HE5T_NATIVE_ULONG         ((hid_t) 7)
-#define    HE5T_NATIVE_LLONG         ((hid_t) 8)
-#define    HE5T_NATIVE_ULLONG        ((hid_t) 9)
-#define    HE5T_NATIVE_FLOAT        ((hid_t) 10)
-#define    HE5T_NATIVE_REAL         ((hid_t) 10)
-#define    HE5T_NATIVE_DOUBLE       ((hid_t) 11)
-#define    HE5T_NATIVE_LDOUBLE      ((hid_t) 12)
-#define    HE5T_NATIVE_INT8         ((hid_t) 13)
-#define    HE5T_NATIVE_UINT8        ((hid_t) 14)
-#define    HE5T_NATIVE_INT16        ((hid_t) 15)
-#define    HE5T_NATIVE_UINT16       ((hid_t) 16)
-#define    HE5T_NATIVE_INT32        ((hid_t) 17)
-#define    HE5T_NATIVE_UINT32       ((hid_t) 18)
-#define    HE5T_NATIVE_INT64        ((hid_t) 19)
-#define    HE5T_NATIVE_UINT64       ((hid_t) 20)
-#define    HE5T_NATIVE_B8           ((hid_t) 21)
-#define    HE5T_NATIVE_B16          ((hid_t) 22)
-#define    HE5T_NATIVE_B32          ((hid_t) 23)
-#define    HE5T_NATIVE_B64          ((hid_t) 24)
-#define    HE5T_NATIVE_HSIZE        ((hid_t) 25)
-#define    HE5T_NATIVE_HERR         ((hid_t) 26)
-#define    HE5T_NATIVE_HBOOL        ((hid_t) 27)
-#define    HE5T_STD_I8BE            ((hid_t) 28)
-#define    HE5T_STD_I8LE            ((hid_t) 29)
-#define    HE5T_STD_I16BE           ((hid_t) 30)
-#define    HE5T_STD_I16LE           ((hid_t) 31)
-#define    HE5T_STD_I32BE           ((hid_t) 32)
-#define    HE5T_STD_I32LE           ((hid_t) 33)
-#define    HE5T_STD_I64BE           ((hid_t) 34)
-#define    HE5T_STD_I64LE           ((hid_t) 35)
-#define    HE5T_STD_U8BE            ((hid_t) 36)
-#define    HE5T_STD_U8LE            ((hid_t) 37)
-#define    HE5T_STD_U16BE           ((hid_t) 38)
-#define    HE5T_STD_U16LE           ((hid_t) 39)
-#define    HE5T_STD_U32BE           ((hid_t) 40)
-#define    HE5T_STD_U32LE           ((hid_t) 41)
-#define    HE5T_STD_U64BE           ((hid_t) 42)
-#define    HE5T_STD_U64LE           ((hid_t) 43)
-#define    HE5T_STD_B8BE            ((hid_t) 44)
-#define    HE5T_STD_B8LE            ((hid_t) 45)
-#define    HE5T_STD_B16BE           ((hid_t) 46)
-#define    HE5T_STD_B16LE           ((hid_t) 47)
-#define    HE5T_STD_B32BE           ((hid_t) 48)
-#define    HE5T_STD_B32LE           ((hid_t) 49)
-#define    HE5T_STD_B64BE           ((hid_t) 50)
-#define    HE5T_STD_B64LE           ((hid_t) 51)
-#define    HE5T_IEEE_F32BE          ((hid_t) 52)
-#define    HE5T_IEEE_F32LE          ((hid_t) 53)
-#define    HE5T_IEEE_F64BE          ((hid_t) 54)
-#define    HE5T_IEEE_F64LE          ((hid_t) 55)
-#define    HE5T_NATIVE_CHAR         ((hid_t) 56)
-#define    HE5T_CHARSTRING          ((hid_t) 57)
+#define    HE5T_NATIVE_INT           0 
+#define    HE5T_NATIVE_UINT          1 
+#define    HE5T_NATIVE_SHORT         2 
+#define    HE5T_NATIVE_USHORT        3 
+#define    HE5T_NATIVE_SCHAR         4 
+#define    HE5T_NATIVE_UCHAR         5 
+#define    HE5T_NATIVE_LONG          6 
+#define    HE5T_NATIVE_ULONG         7 
+#define    HE5T_NATIVE_LLONG         8 
+#define    HE5T_NATIVE_ULLONG        9 
+#define    HE5T_NATIVE_FLOAT        10 
+#define    HE5T_NATIVE_REAL         10
+#define    HE5T_NATIVE_DOUBLE       11 
+#define    HE5T_NATIVE_LDOUBLE      12 
+#define    HE5T_NATIVE_INT8         13 
+#define    HE5T_NATIVE_UINT8        14 
+#define    HE5T_NATIVE_INT16        15 
+#define    HE5T_NATIVE_UINT16       16 
+#define    HE5T_NATIVE_INT32        17 
+#define    HE5T_NATIVE_UINT32       18 
+#define    HE5T_NATIVE_INT64        19 
+#define    HE5T_NATIVE_UINT64       20 
+#define    HE5T_NATIVE_B8           21 
+#define    HE5T_NATIVE_B16          22 
+#define    HE5T_NATIVE_B32          23 
+#define    HE5T_NATIVE_B64          24 
+#define    HE5T_NATIVE_HSIZE        25 
+#define    HE5T_NATIVE_HERR         26 
+#define    HE5T_NATIVE_HBOOL        27 
+#define    HE5T_STD_I8BE            28 
+#define    HE5T_STD_I8LE            29 
+#define    HE5T_STD_I16BE           30 
+#define    HE5T_STD_I16LE           31 
+#define    HE5T_STD_I32BE           32 
+#define    HE5T_STD_I32LE           33 
+#define    HE5T_STD_I64BE           34 
+#define    HE5T_STD_I64LE           35 
+#define    HE5T_STD_U8BE            36 
+#define    HE5T_STD_U8LE            37 
+#define    HE5T_STD_U16BE           38 
+#define    HE5T_STD_U16LE           39 
+#define    HE5T_STD_U32BE           40 
+#define    HE5T_STD_U32LE           41 
+#define    HE5T_STD_U64BE           42 
+#define    HE5T_STD_U64LE           43 
+#define    HE5T_STD_B8BE            44 
+#define    HE5T_STD_B8LE            45 
+#define    HE5T_STD_B16BE           46 
+#define    HE5T_STD_B16LE           47 
+#define    HE5T_STD_B32BE           48 
+#define    HE5T_STD_B32LE           49 
+#define    HE5T_STD_B64BE           50 
+#define    HE5T_STD_B64LE           51 
+#define    HE5T_IEEE_F32BE          52                 
+#define    HE5T_IEEE_F32LE          53                 
+#define    HE5T_IEEE_F64BE          54                 
+#define    HE5T_IEEE_F64LE          55                 
+#define    HE5T_NATIVE_CHAR         56
+#define    HE5T_CHARSTRING          57
 
-#define    HE5S_UNLIMITED_F         ((hid_t) -1)
-#define    HE5S_UNLIMITED_F_64      ((hid_t) -1)
+#define    HE5S_UNLIMITED_F         -1 
+#define    HE5S_UNLIMITED_F_64      -1 
 
 
 /* Field Merge Flags   */
@@ -377,7 +375,7 @@ typedef  struct
 #define HE5_HDFE_COMP_SZIP_NN             8
 #define HE5_HDFE_COMP_SZIP_K13orEC        9
 #define HE5_HDFE_COMP_SZIP_K13orNN       10
-#define HE5_HDFE_COMP_SHUF_DEFLATE       11
+#define HE5_HDFE_COMP_SHUF_DEFLATE       11 
 #define HE5_HDFE_COMP_SHUF_SZIP_CHIP     12
 #define HE5_HDFE_COMP_SHUF_SZIP_K13      13
 #define HE5_HDFE_COMP_SHUF_SZIP_EC       14
@@ -395,7 +393,7 @@ typedef  struct
 #define HE5_HDFE_LOCATTRGROUP       4
 #define HE5_HDFE_PROFGROUP          5
 #define HE5_HDFE_PROFGRPATTRGROUP   6
-#define HE5_HDFE_GEOGRPATTRGROUP    7
+#define HE5_HDFE_GEOGRPATTRGROUP    7   
 
 
 /*
@@ -415,7 +413,7 @@ typedef struct
 } HE5_HDFE_MutexStruct;
 
 
-extern HE5_HDFE_MutexStruct   GlobalMutex;
+HE5_HDFE_MutexStruct   GlobalMutex;
 
 
 /* Macro for first thread initialization */
@@ -464,18 +462,17 @@ extern "C" {
 
 /* Thread-safe function prototypes */
 /* ------------------------------- */
-void
+void    
 HE5_TSinitfirst( void);
-herr_t
+herr_t   
 HE5_TSmutexlock(HE5_HDFE_MutexStruct *);
-herr_t
+herr_t   
 HE5_TSmutexunlock(HE5_HDFE_MutexStruct *);
 
 /* GCTP function prototypes */
 /* ------------------------ */
-/*
 #include  "HE5_GctpFunc.h"
-*/
+
 /* HDF5 Error handling function (from "H5private.h") */
 /* ------------------------------------------------- */
 herr_t   H5E_push(H5E_major_t maj_num, H5E_minor_t min_num, const char *func_name, const char *file_name, unsigned line, const char *desc);
@@ -496,10 +493,7 @@ herr_t   HE5_EHchkfid(hid_t fid, const char *name, hid_t *HDFfid, hid_t *grpID,
 herr_t   HE5_EHidinfo(hid_t fid, hid_t *HDFfid, hid_t *gid);
 long     HE5_EHattrcat(hid_t fid,   char *grpname, char *objectlist, long *strbufsize);
 long     HE5_EHinquire(const char *filename, char *grpname, char *objectlist, long *strbufsize);
-hsize_t  HE5_EHset_error_on(int flag, int err_level);
-herr_t   HE5_EHwritemeta(hid_t fid, const char *MetadataName, char *metabuff);
-herr_t   HE5_EHreadmeta(hid_t fid, const char *MetadataName, char *metabufout, long *bufferSize);
-long HE5_EHinqmetadatas(hid_t fid, char *metadatanames, long *strbufsize);
+hsize_t HE5_EHset_error_on(int flag, int err_level);
 
 /* PROTOTYPES: functions to turn HDFEOS5 error printing off */
 herr_t HE5_EHprint(char *errbuf, const char *file, unsigned line);
@@ -519,7 +513,6 @@ long     HE5_EHcntOBJECT(char *metabuf[]);
 long     HE5_EHcntGROUP(char *metabuf[]);
 herr_t   HE5_EHattr( hid_t attgrpID, const char *attrname, hid_t ntype, hsize_t count[], char *wrcode, void *datbuf);
 herr_t   HE5_EHattrinfo( hid_t attgrpID, const char *attrname, hid_t ntype[], hsize_t *count);
-herr_t   HE5_EHattrinfo2( hid_t attgrpID, const char *attrname, hid_t ntype[], hsize_t *count,  hsize_t *size);
 long     HE5_EHdatasetcat(hid_t fid,  char *grpname, char *objectlist, long  *strbufsize);
 int      HE5_EHobj_info(hid_t loc_id, const char *name, void *opdata);
 
@@ -527,25 +520,22 @@ int      HE5_EHobj_info(hid_t loc_id, const char *name, void *opdata);
 
 long     HE5_EHparsestr(const char *instring, char delim, char *pntr[], size_t len[]);
 long     HE5_EHstrwithin(char *target, char *search, char delim);
-long     HE5_EHstrwithin_index(char *target, char *search, char delim,int* index_found);
-
 herr_t   HE5_EHloadliststr(char *ptr[], long nentries, char *liststr, char delim);
 double   HE5_EHconvAng(double inAngle, int code);
 herr_t   HE5_EHrevflds(char *dimlist, char *revdimlist);
 herr_t   HE5_EHbisect(double(*func) (double[]), double funcParms[], long nParms, double limLft, double limRgt, double convCrit, double *root);
 hid_t    HE5_EHdtype2mtype(hid_t dtypeID);
 hid_t    HE5_EHdtype2numtype(hid_t dtype);
-hid_t    HE5_EHconvdatatype(hid_t fortdatatype);
+hid_t    HE5_EHconvdatatype(int fortdatatype);
 herr_t   HE5_EHwriteglbattr(hid_t fid, const char *attrname, hid_t ntype, hsize_t  count[], void *datbuf);
 herr_t   HE5_EHreadglbattr(hid_t fid, const char *attrname, void * datbuf);
 herr_t   HE5_EHglbattrinfo(hid_t fid, const char *attrname, hid_t *ntype, hsize_t *count);
-herr_t   HE5_EHglbattrinfo2(hid_t fid, const char *attrname, hid_t *ntype, hsize_t *count, hsize_t *size);
 long     HE5_EHinqglbattrs(hid_t fid, char *attrnames, long *strbufsize);
 herr_t   HE5_EHinqglbdatatype(hid_t fid, const char *attrname, hid_t *dtype, H5T_class_t *classid, H5T_order_t *order, size_t *size);
 int      HE5_szip_can_encode(void );
 
-/* Data type conversion wrappers */
-
+/* Data type conversion wrappers */    
+                      
 long                 HE5_EHhid2long(hid_t invalue);
 long                 HE5_EHint2long(int invalue);
 int                  HE5_EHhid2int(hid_t invalue);
@@ -575,13 +565,13 @@ long                 HE5_EHullong2long(unsigned LONGLONG invalue);
 herr_t               HE5_EHchkptr(void *p, char *name);
 herr_t               HE5_EHchkname(char *p, char *name);
 
-int                  HE5_EHHEisHE5(char *filename);
+
 /*
  **********************************************************************
  *                    S W A T H    I N T E R F A C E                  *
  **********************************************************************
  */
-
+  
 
 
 /* File/Swath access routines */
@@ -639,10 +629,6 @@ herr_t  HE5_SWattrinfo(hid_t swathID, const char *attrname, hid_t *ntype, hsize_
 herr_t  HE5_SWgrpattrinfo(hid_t swathID, const char *attrname, hid_t *ntype, hsize_t *count);
 herr_t  HE5_SWgeogrpattrinfo(hid_t swathID, const char *attrname, hid_t *ntype, hsize_t *count);
 herr_t  HE5_SWlocattrinfo(hid_t swathID, const char *fieldname, const char *attrname, hid_t *ntype, hsize_t *count);
-herr_t  HE5_SWattrinfo2(hid_t swathID, const char *attrname, hid_t *ntype, hsize_t *count, hsize_t *size);
-herr_t  HE5_SWgrpattrinfo2(hid_t swathID, const char *attrname, hid_t *ntype, hsize_t *count, hsize_t *size);
-herr_t  HE5_SWgeogrpattrinfo2(hid_t swathID, const char *attrname, hid_t *ntype, hsize_t *count, hsize_t *size);
-herr_t  HE5_SWlocattrinfo2(hid_t swathID, const char *fieldname, const char *attrname, hid_t *ntype, hsize_t *count, hsize_t *size);
 herr_t  HE5_SWinqdatatype(hid_t swathID, const char *fieldname, const char *attrname, int group, hid_t *dtype, H5T_class_t *classid, H5T_order_t *order, size_t *size);
 long    HE5_SWinqdims(hid_t swathID, char *dimnames, hsize_t dims[]);
 long    HE5_SWinqmaps(hid_t swathID, char *dimmaps, long offset[], long increment[]);
@@ -665,7 +651,6 @@ long    HE5_SWinqgfldalias(hid_t swathID, char *fldalias, long *strbufsize);
 long    HE5_SWgetaliaslist(hid_t swathID, int fldgroup, char *aliaslist, long *strbufsize);
 long    HE5_SWgetdimscale(hid_t swathID, char *fieldname, char *dimname, hsize_t *dimsize, hid_t *numbertype, void * databuff);
 herr_t  HE5_SWdscaleattrinfo(hid_t swathID, const char *fieldname, const char *attrname, hid_t *ntype, hsize_t *count);
-herr_t  HE5_SWdscaleattrinfo2(hid_t swathID, const char *fieldname, const char *attrname, hid_t *ntype, hsize_t *count, hsize_t *size);
 herr_t  HE5_SWreaddscaleattr(hid_t swathID, const char *fieldname, const char *attrname, void *datbuf);
 long    HE5_SWinqdscaleattrs(hid_t swathID, const char *fieldname, char *attrnames, long *strbufsize);
 
@@ -686,7 +671,7 @@ herr_t  HE5_SWindexinfo(hid_t regionID, char *object, int *rank, char *dimlist,
  ********************************
  *     PROFILE INTERFACE        *
  ********************************
- */
+ */ 
 
 herr_t  HE5_PRdefine(hid_t swathID, const char *profilename, char *dimlist, char *maxdimlist, hid_t datatype_id);
 herr_t  HE5_PRwrite(hid_t swathID, const char *profilename, const hssize_t start[], const hsize_t stride[], const hsize_t edge[], size_t size, void *buffer);
@@ -697,7 +682,6 @@ herr_t  HE5_PRinfo(hid_t swathID, const char *profname, int *rank, hsize_t dims[
 herr_t  HE5_PRwritegrpattr(hid_t swathID, const char *attrname, hid_t ntype, hsize_t count[], void *datbuf);
 herr_t  HE5_PRreadgrpattr(hid_t swathID, const char *attrname, void *datbuf);
 herr_t  HE5_PRgrpattrinfo(hid_t swathID, const char *attrname, hid_t *ntype, hsize_t *count);
-herr_t  HE5_PRgrpattrinfo2(hid_t swathID, const char *attrname, hid_t *ntype, hsize_t *count, hsize_t *size);
 long    HE5_PRinqgrpattrs(hid_t swathID, char *attrnames, long *strbufsize);
 
 
@@ -716,7 +700,7 @@ int     HE5_SWgetextdata(hid_t swathID, char *fieldname, size_t namelength, char
  *  MOUNTING EXTERNAL FILES    *
  *******************************
  */
-
+  
 hid_t   HE5_SWmountexternal(hid_t swathID, int fldgroup, const char *extfilename);
 herr_t  HE5_SWunmount(hid_t swathID, int fldgroup, hid_t fileID);
 herr_t  HE5_SWreadexternal(hid_t swathID, int fldgroup, const char *fieldname, void *buffer);
@@ -784,9 +768,6 @@ int      HE5_GDinqdims(hid_t gridID, char *dimnames, hsize_t  dims[]);
 herr_t   HE5_GDattrinfo(hid_t gridID, const char *attrname, hid_t *ntype, hsize_t *count);
 herr_t   HE5_GDgrpattrinfo(hid_t gridID, const char *attrname, hid_t *ntype, hsize_t *count);
 herr_t   HE5_GDlocattrinfo(hid_t gridID, const char *fieldname, const char *attrname, hid_t *ntype, hsize_t *count);
-herr_t   HE5_GDattrinfo2(hid_t gridID, const char *attrname, hid_t *ntype, hsize_t *count, hsize_t *size);
-herr_t   HE5_GDgrpattrinfo2(hid_t gridID, const char *attrname, hid_t *ntype, hsize_t *count, hsize_t *size);
-herr_t   HE5_GDlocattrinfo2(hid_t gridID, const char *fieldname, const char *attrname, hid_t *ntype, hsize_t *count, hsize_t *size);
 long     HE5_GDinqattrs(hid_t gridID, char *attrnames, long *strbufsize);
 long     HE5_GDinqgrpattrs(hid_t gridID, char *attrnames, long *strbufsize);
 long     HE5_GDinqlocattrs(hid_t gridID, const char *fieldname, char *attrnames, long *strbufsize);
@@ -800,7 +781,6 @@ long     HE5_GDgetaliaslist(hid_t gridID, int fldgroup, char *aliaslist, long *s
 long     HE5_GDgetdimscale(hid_t gridID, char *fieldname, char *dimname, hsize_t *dimsize, hid_t *numbertype, void * databuff);
 herr_t   HE5_GDwritedscaleattr(hid_t gridID, const char *fieldname, const char *attrname, hid_t numtype, hsize_t  count[],  void *datbuf);
 herr_t   HE5_GDdscaleattrinfo(hid_t gridID, const char *fieldname, const char *attrname, hid_t *ntype, hsize_t *count);
-herr_t   HE5_GDdscaleattrinfo2(hid_t gridID, const char *fieldname, const char *attrname, hid_t *ntype, hsize_t *count, hsize_t *size);
 herr_t   HE5_GDreaddscaleattr(hid_t gridID, const char *fieldname, const char *attrname, void *datbuf);
 long     HE5_GDinqdscaleattrs(hid_t gridID, const char *fieldname, char *attrnames, long *strbufsize);
 
@@ -808,7 +788,7 @@ long     HE5_GDinqdscaleattrs(hid_t gridID, const char *fieldname, char *attrnam
 
 hid_t    HE5_GDdefboxregion(hid_t gridID, double cornerlon[], double cornerlat[]);
 hid_t    HE5_GDdefvrtregion(hid_t gridID, hid_t regionID, char *vertObj, double range[]);
-hid_t   HE5_GDdeftimeperiod(hid_t gridID, hid_t periodID, double starttime, double stoptime);
+herr_t   HE5_GDdeftimeperiod(hid_t gridID, hid_t periodID, double starttime, double stoptime);
 herr_t   HE5_GDextractregion(hid_t gridID, hid_t regionID, const char *fieldname, void *buffer);
 hid_t    HE5_GDdupregion(hid_t oldregionID);
 herr_t   HE5_GDgetpixels(hid_t gridID, long nLonLat, double lonVal[], double latVal[], long pixRow[], long pixCol[]);
@@ -884,9 +864,6 @@ herr_t   HE5_PTgetrecnums(hid_t pointID, int inlevel, int outlevel, hsize_t inNr
 herr_t   HE5_PTattrinfo(hid_t pointID, const char *attrname, hid_t *ntype, hsize_t *count);
 herr_t   HE5_PTgrpattrinfo(hid_t pointID, const char *attrname, hid_t *ntype, hsize_t *count);
 herr_t   HE5_PTlocattrinfo(hid_t pointID, const char *levelname, const char *attrname, hid_t *ntype, hsize_t *count);
-herr_t   HE5_PTattrinfo2(hid_t pointID, const char *attrname, hid_t *ntype, hsize_t *count, hsize_t *size);
-herr_t   HE5_PTgrpattrinfo2(hid_t pointID, const char *attrname, hid_t *ntype, hsize_t *count, hsize_t *size);
-herr_t   HE5_PTlocattrinfo2(hid_t pointID, const char *levelname, const char *attrname, hid_t *ntype, hsize_t *count, hsize_t *size);
 long     HE5_PTinqattrs(hid_t pointID, char *attrnames, long *strbufsize);
 long     HE5_PTinqgrpattrs(hid_t pointID, char *attrnames, long *strbufsize);
 long     HE5_PTinqlocattrs(hid_t pointID, const char *levelname, char *attrnames, long *strbufsize);
@@ -897,19 +874,19 @@ long     HE5_PTinqlocattrs(hid_t pointID, const char *levelname, char *attrnames
  *                    Z A    I N T E R F A C E                        *
  **********************************************************************
  */
-
-
+ 
+ 
 /* File/ZA access routines */
-
+ 
 hid_t   HE5_ZAopen(const char *filename, uintn flags);
 hid_t   HE5_ZAcreate(hid_t fid, const char *zaname);
 hid_t   HE5_ZAattach(hid_t fid, const char *zaname);
 herr_t  HE5_ZAdetach(hid_t zaID);
 herr_t  HE5_ZAclose(hid_t fid);
-
-
+ 
+ 
 /* Definition routines */
-
+ 
 herr_t  HE5_ZAdefdim(hid_t zaID,  char *dimname, hsize_t dim);
 herr_t  HE5_ZAdefine(hid_t zaID, const char *za_name, char *dimlist, char *maxdimlist, hid_t dtype);
 herr_t  HE5_ZAdefchunk(hid_t zaID, int ndims, const hsize_t *dim);
@@ -924,7 +901,7 @@ long    HE5_ZAgetdimscale(hid_t zaID, char *fieldname, char *dimname, hsize_t *d
 herr_t  HE5_ZAdefdimscale(hid_t zaID, char *dimname, const hsize_t dimsize, hid_t numbertype, void * datbuff);
 
 /* I/O routines */
-
+ 
 herr_t  HE5_ZAwritedatameta(hid_t zaID, const char *fieldname, char *dimlist, hid_t mvalue);
 herr_t  HE5_ZAwriteattr(hid_t zaID, const char *attrname, hid_t ntype, hsize_t count[], void *datbuf);
 herr_t  HE5_ZAwritegrpattr(hid_t zaID, const char *attrname, hid_t ntype, hsize_t count[], void *datbuf);
@@ -934,11 +911,11 @@ herr_t  HE5_ZAreadgrpattr(hid_t zaID, const char *attrname, void *datbuf);
 herr_t  HE5_ZAreadlocattr(hid_t zaID, const char *fieldname, const char *attrname, void *datbuf);
 herr_t  HE5_ZAwrite(hid_t zaID, char *za_name, const hssize_t start[], const hsize_t stride[], const hsize_t count[],  void *datbuf);
 herr_t  HE5_ZAread(hid_t zaID, char *za_name, const hssize_t start[], const hsize_t stride[], const hsize_t count[],  void *datbuf);
-herr_t  HE5_ZAreaddscaleattr(hid_t zaID, const char *fieldname, const char *attrname, void *datbuf);
-herr_t  HE5_ZAwritedscaleattr(hid_t zaID, const char *fieldname, const char *attrname, hid_t numtype, hsize_t  count[],  void *datbuf);
-
+herr_t HE5_ZAreaddscaleattr(hid_t zaID, const char *fieldname, const char *attrname, void *datbuf);
+herr_t HE5_ZAwritedscaleattr(hid_t zaID, const char *fieldname, const char *attrname, hid_t numtype, hsize_t  count[],  void *datbuf); 
+ 
 /* Inquiry routines */
-
+ 
 hsize_t HE5_ZAdiminfo(hid_t zaID, char *dimname);
 int     HE5_ZAfldsrch(hid_t zaID, char *fieldname, hid_t *fieldID, int *rank,  hsize_t dims[], hid_t *typeID);
 herr_t  HE5_ZAinfo(hid_t zaID, char *za_name, int *rank, hsize_t dims[], hid_t dtype[], char *dimlist, char *maxdimlist);
@@ -946,9 +923,6 @@ herr_t  HE5_ZAcompinfo(hid_t zaID, char *fieldname, int *compcode, int compparm[
 herr_t  HE5_ZAattrinfo(hid_t zaID, const char *attrname, hid_t *ntype, hsize_t *count);
 herr_t  HE5_ZAgrpattrinfo(hid_t zaID, const char *attrname, hid_t *ntype, hsize_t *count);
 herr_t  HE5_ZAlocattrinfo(hid_t zaID, const char *fieldname, const char *attrname, hid_t *ntype, hsize_t *count);
-herr_t  HE5_ZAattrinfo2(hid_t zaID, const char *attrname, hid_t *ntype, hsize_t *count, hsize_t *size);
-herr_t  HE5_ZAgrpattrinfo2(hid_t zaID, const char *attrname, hid_t *ntype, hsize_t *count, hsize_t *size);
-herr_t  HE5_ZAlocattrinfo2(hid_t zaID, const char *fieldname, const char *attrname, hid_t *ntype, hsize_t *count, hsize_t *size);
 herr_t  HE5_ZAinqdatatype(hid_t zaID, const char *fieldname, const char *attrname, int group, hid_t *dtype, H5T_class_t *classid, H5T_order_t *order, size_t *size);
 long    HE5_ZAinqdims(hid_t zaID, char *dimnames, hsize_t dims[]);
 long    HE5_ZAinquire(hid_t zaID, char *za_name_list, int rank[], hid_t dtype[]);
@@ -962,26 +936,25 @@ herr_t  HE5_ZAaliasinfo(hid_t zaID, int fldgroup, const char *aliasname, int *le
 long    HE5_ZAinqfldalias(hid_t zaID, char *fldalias, long *strbufsize);
 herr_t  HE5_ZAchunkinfo(hid_t zaID, char *fieldname, int *ndims, hsize_t dims[]);
 long    HE5_ZAgetaliaslist(hid_t zaID, int fldgroup, char *aliaslist, long *strbufsize);
-herr_t  HE5_ZAdscaleattrinfo(hid_t zaID, const char *fieldname, const char *attrname, hid_t *ntype, hsize_t *count);
-herr_t  HE5_ZAdscaleattrinfo2(hid_t zaID, const char *fieldname, const char *attrname, hid_t *ntype, hsize_t *count, hsize_t *size);
-long    HE5_ZAinqdscaleattrs(hid_t zaID, const char *fieldname, char *attrnames, long *strbufsize);
+herr_t HE5_ZAdscaleattrinfo(hid_t zaID, const char *fieldname, const char *attrname, hid_t *ntype, hsize_t *count);
+long HE5_ZAinqdscaleattrs(hid_t zaID, const char *fieldname, char *attrnames, long *strbufsize);
 
 /*
  *******************************
  *   EXTERNAL DATA FILES       *
  *******************************
  */
-
+ 
 herr_t  HE5_ZAsetextdata(hid_t zaID, const char *filelist, off_t offset[], hsize_t size[]);
 int     HE5_ZAgetextdata(hid_t zaID, char *fieldname, size_t namelength, char *filelist, off_t offset[], hsize_t size[]);
-
-
+ 
+ 
 /*
  *******************************
  *  MOUNTING EXTERNAL FILES    *
  *******************************
  */
-
+ 
 hid_t   HE5_ZAmountexternal(hid_t zaID, int fldgroup, const char *extfilename);
 herr_t  HE5_ZAunmount(hid_t zaID, int fldgroup, hid_t fileID);
 herr_t  HE5_ZAreadexternal(hid_t zaID, int fldgroup, const char *fieldname, void *buffer);
@@ -994,3 +967,15 @@ herr_t  HE5_ZAreadexternal(hid_t zaID, int fldgroup, const char *fieldname, void
 
 
 #endif  /* #ifndef HE5_HDFEOSDEF_H_ */
+
+
+
+
+
+
+
+
+
+
+
+
