@@ -200,7 +200,7 @@
   230 format('********Error unexpected**********')
   240 format('***********Passed Test*********')
 
-      open(unit=1, file="testza64_f.txtout", status = "UNKNOWN")
+      open(unit=1, file="testza.txt", status = "UNKNOWN")
 
       write(*,*)'Testing he5_za FORTRAN 77 interface'
       write(*,*)'======================================'
